package main

import (
	"context"
	"fmt"
	"io"
	"net/url"
	"os"

	"gitea.stevedudenhoeffer.com/steve/go-extractor/cmd/browser/pkg/browser"
	"gitea.stevedudenhoeffer.com/steve/go-extractor/sites/aislegopher"
	"github.com/urfave/cli/v3"
)

type AisleGopherFlags []cli.Flag

var Flags = AisleGopherFlags{}

func (f AisleGopherFlags) ToConfig(_ *cli.Command) aislegopher.Config {
	res := aislegopher.DefaultConfig

	return res
}

func deferClose(cl io.Closer) {
	if cl != nil {
		_ = cl.Close()
	}
}
func main() {
	var flags []cli.Flag
	flags = append(flags, browser.Flags...)
	flags = append(flags, Flags...)

	cli := &cli.Command{
		Name:  "aislegopher",
		Usage: "AisleGopher is a tool for extracting data from aislegopher.com",
		Flags: flags,
		Action: func(ctx context.Context, c *cli.Command) error {
			cfg := Flags.ToConfig(c)

			b, err := browser.FromCommand(ctx, c)
			if err != nil {
				return fmt.Errorf("failed to create browser: %w", err)
			}

			defer deferClose(b)

			arg := c.Args().First()

			if arg == "" {
				return fmt.Errorf("url is required")
			}

			u, err := url.Parse(arg)

			if err != nil {
				return fmt.Errorf("failed to parse url: %w", err)
			}

			data, err := cfg.GetItemFromURL(ctx, b, u)

			if err != nil {
				return fmt.Errorf("failed to get item from url: %w", err)
			}

			fmt.Printf("Item: %+v\n", data)
			return nil
		},
	}

	err := cli.Run(context.Background(), os.Args)

	if err != nil {
		panic(err)
	}
}
